# pyiron_contrib

This repository is for user developments on top of the pyiron platform, existing as a publicly accessible incubation area for new ideas. As such, code here might be very useful and cutting-edge, but comes without the level of stability or backwards compatibility associated with the main pyiron branch.
